@@ -33,6 +33,7 @@ type App interface {
 	Status(extended bool) error
 	Version() error
 	Runtime() (string, error)
+	Update() error
 	Kubernetes() (environment.Container, error)
 }
 
@@ -454,6 +455,41 @@ func (c colimaApp) Active() bool {
 	return c.guest.Running(context.Background())
 }
 
+func (c *colimaApp) Update() error {
+	ctx := context.Background()
+	if !c.guest.Running(ctx) {
+		return fmt.Errorf("runtime cannot be updated, %s is not running", config.CurrentProfile().DisplayName)
+	}
+
+	runtime, err := c.currentRuntime(ctx)
+	if err != nil {
+		return err
+	}
+
+	container, err := c.containerEnvironment(runtime)
+	if err != nil {
+		return err
+	}
+
+	oldVersion := container.Version(ctx)
+
+	updated, err := container.Update(ctx)
+	if err != nil {
+		return err
+	}
+
+	if updated {
+		fmt.Println()
+		fmt.Println("Previous")
+		fmt.Println(oldVersion)
+		fmt.Println()
+		fmt.Println("Current")
+		fmt.Println(container.Version(ctx))
+	}
+
+	return nil
+}
+
 func generateSSHConfig(modifySSHConfig bool) error {
 	instances, err := limautil.Instances()
 	if err != nil {
