@@ -28,6 +28,10 @@ If you simply want to reset the Kubernetes cluster, run 'colima kubernetes reset
 			if !y {
 				return nil
 			}
+			yy := cli.Prompt("\033[31m\033[1mthis will delete ALL container data. Are you sure you want to continue")
+			if !yy {
+				return nil
+			}
 		}
 
 		return newApp().Delete()
