@@ -16,6 +16,7 @@ type Config struct {
 	CPUs                 *int              `yaml:"cpus,omitempty"`
 	Memory               string            `yaml:"memory,omitempty"`
 	Disk                 string            `yaml:"disk,omitempty"`
+	AdditionalDisks      []Disk            `yaml:"additionalDisks,omitempty" json:"additionalDisks,omitempty"`
 	Mounts               []Mount           `yaml:"mounts,omitempty"`
 	MountType            MountType         `yaml:"mountType,omitempty" json:"mountType,omitempty"`
 	SSH                  SSH               `yaml:"ssh"`
@@ -45,6 +46,13 @@ type Mount struct {
 	NineP      NineP  `yaml:"9p,omitempty" json:"9p,omitempty"`
 }
 
+type Disk struct {
+	Name   string   `yaml:"name" json:"name"` // REQUIRED
+	Format *bool    `yaml:"format,omitempty" json:"format,omitempty"`
+	FSType *string  `yaml:"fsType,omitempty" json:"fsType,omitempty"`
+	FSArgs []string `yaml:"fsArgs,omitempty" json:"fsArgs,omitempty"`
+}
+
 type SSH struct {
 	LocalPort         int  `yaml:"localPort,omitempty"`
 	LoadDotSSHPubKeys bool `yaml:"loadDotSSHPubKeys"`
